# Charles Kurzman, University of North Carolina at Chapel Hill
# Analysis of Delphi Covid-19 survey

library(survey)
library(ggplot2)
library(dplyr)

# Open csv
setwd("c:/d/archive/cmu/")
#r <- read.csv("cmu-data-2020-09-09.csv", stringsAsFactors = FALSE)

# Create smaller dataset with selected variables:

s <- data.frame(matrix(, nrow = nrow(r), ncol = 0))
s$weight <- r$weight
s$date <- r$date

# Testing
table(r$B5) # Tested? 1=Positive, 2=Negative, 3=No result, 4=Tried, 5=Haven't tried
table(str_detect(r$B2,"15")) # No symptoms
s$tested <- case_when(
  r$B5 == 1 ~ "1. Positive",
  r$B5 == 2 ~ "2. Negative",
  r$B5 == 3 ~ "3. No result",
  r$B5 == 4 ~ "4. Tried",
  r$B5 == 5 ~ "5. Haven't tried",
  str_detect(r$B2,"15") ~ "6. No symptoms"
)
#table(s$tested)

# Tested positive
s$testpos <- case_when(
  r$B5 == 1 ~ 100,
  r$B5 != 1 ~ 0,
  r$B2 == "15" ~ 0
)
#table(s$testpos)

# Covid-like symptoms (from definition in question A1, fever plus one other symptom)
s$ili <- case_when(
  str_detect(r$B2,"1,") & str_detect(r$B2,"2") ~ 100,
  str_detect(r$B2,"1,") & str_detect(r$B2,"3") ~ 100,
  str_detect(r$B2,"1,") & str_detect(r$B2,"4") ~ 100,
  str_detect(r$B2,"1,") & str_detect(r$B2,"9") ~ 100,
  !is.na(r$B2) ~ 0
)
#table(s$ili)

# 5-day recent onset of symptoms (not counting respondents with earlier onset of symptoms)
summary(r$B2b) # How many days experiencing symptoms
s$ili5 <- case_when(
  r$B2b < 5 & s$ili == 100 ~ 100,
  s$ili !=100  ~ 0
)
#table(s$ili5)

# Work in past 5 days
s$work <- factor(r$C3, labels = c("Work","No work"))
#table(s$work)

# Work in healthcare
table(r$C4) # Work in hospital etc., 1=Yes, 2=No
s$healthcare <- factor(r$C4, labels = c("Yes","No"))
#table(s$healthcare)

# Work in eldercare
table(r$C5) # Long-term care facility or nursing home, 1=Yes, 2=No
s$eldercare <- r$eldercare <- factor(r$C5, labels = c("Yes","No"))
#table(s$eldercare)

# Work in healthcare or eldercare
s$healthelder <- case_when(
  r$C4!=1 & r$C5!=1 ~ 0,
  r$C4==1 | r$C5==1 ~ 1
)
#table(s$healthelder)

# Poverty, lowest quartile, Census zipcode data
povertyq <- read.csv("c:/d/archive/CMU/zipcodes/medianincomequartiles.csv", stringsAsFactors = FALSE)
povertyq # Quartiles of median income
s$povertyq1 <- case_when(
  r$medianincome <= povertyq$x[2] ~ 1,
  r$medianincome > povertyq$x[2] ~ 0
)
#table(s$povertyq1)

# Majority-minority zipcodes, Census zipcode data
summary(r$whitealonepct)
s$majorityminority <- case_when(
  r$whitealonepct >= 50 ~ 0,
  r$whitealonepct < 50 ~ 1
)
#table(s$majorityminority)


# CREATE DAILY SUMMARY FILE

daily <- filelist
daily$date <- as.Date(daily$responsedate,format="%Y_%m_%d")
daily <- daily[daily$responsedate != "2020_09_08",] # DROP LAST DAY - ONLY 1 OBSERVATION
daily$n <- count(s, date)[[2]]
daily$endrow <- cumsum(daily$n)
daily$startrow <- lag(daily$endrow) + 1
daily$startrow[1] <- 1

# Active confirmed cases of COVID-19 from Johns Hopkins University Coronavirus Research Center datafiles
daily$jhuconfirmed = NA
daily$jhuactive = NA
start <- as.Date("2020-04-12",format="%Y-%m-%d")
end   <- as.Date(max(daily$date),format="%Y-%m-%d")
d <- start
while(d<=end) {
  localfile <- paste("c:/d/archive/CMU/JHU/JHU-",format(d, "%Y-%m-%d"),".csv", sep="")
  temp <- read_csv(localfile)
  confirmed <- sum(temp$Confirmed, na.rm=TRUE)
  active <- sum(temp$Active, na.rm=TRUE)
  daily$jhuconfirmed[daily$date==d] <- confirmed
  daily$jhuactive[daily$date==d] <- active
  d <- d+1
  rm(localfile)
  rm(temp)
}
daily$jhuactive <- 100*daily$jhuactive/330000000          # Recalculated as percent of US population
daily$jhunew <- c(NA, diff(daily$jhuconfirmed, differences = 1))  # New confirmed cases
daily$jhunew <- 100*daily$jhunew/330000000                # Recalculated as percent of US population
daily$jhuconfirmed <- 100*daily$jhuconfirmed/330000000    # Recalculated as percent of US population


daily$testpos <- NA
daily$testpos_se <- NA
daily$healthelder <- NA
daily$healthelder_se <- NA
daily$nonhealthelder <- NA
daily$nonhealthelder_se <- NA
daily$healthcare <- NA
daily$healthcare_se <- NA
daily$eldercare <- NA
daily$eldercare_se <- NA
daily$workers <- NA
daily$workers_se <- NA
daily$nonworkers <- NA
daily$nonworkers_se <- NA
daily$mm <- NA
daily$mm_se <- NA
daily$mw <- NA
daily$mw_se <- NA
daily$q1 <- NA
daily$q1_se <- NA
daily$q24 <- NA
daily$q24_se <- NA

#for(d in 1:nrow(daily)){
for(d in (nrow(daily)-4):nrow(daily)){
  print(daily$date[d])
  temp <- s[daily$startrow[d]:daily$endrow[d],]

  # Incorporate survey weights
  w <- svydesign(ids = ~1, data = temp, weights = ~weight)
  
  # Run models, get means and standard errors
  dailytemp <- svymean(w$variables$testpos, design = w, na.rm = TRUE, deff = TRUE)
  daily$testpos[d] <- coef(dailytemp)
  daily$testpos_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$testpos[w$variables$healthelder==1], design = w[w$variables$healthelder==1], na.rm = TRUE, deff = TRUE)
  daily$healthelder[d] <- coef(dailytemp)
  daily$healthelder_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$testpos[w$variables$healthelder==0], design = w[w$variables$healthelder==0], na.rm = TRUE, deff = TRUE)
  daily$nonhealthelder[d] <- coef(dailytemp)
  daily$nonhealthelder_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$testpos[w$variables$healthcare=="Yes"], design = w[w$variables$healthcare=="Yes"], na.rm = TRUE, deff = TRUE)
  daily$healthcare[d] <- coef(dailytemp)
  daily$healthcare_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$testpos[w$variables$eldercare=="Yes"], design = w[w$variables$eldercare=="Yes"], na.rm = TRUE, deff = TRUE)
  daily$eldercare[d] <- coef(dailytemp)
  daily$eldercare_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$ili5[w$variables$work == "Work"], design = w[w$variables$work == "Work"], na.rm = TRUE, deff = TRUE)
  daily$workers[d] <- coef(dailytemp)
  daily$workers_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$ili5[w$variables$work == "No work"], design = w[w$variables$work == "No work"], na.rm = TRUE, deff = TRUE)
  daily$nonworkers[d] <- coef(dailytemp)
  daily$nonworkers_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$testpos[w$variables$majorityminority == 1], design = w[w$variables$majorityminority == 1], na.rm = TRUE, deff = TRUE)
  daily$mm[d] <- coef(dailytemp)
  daily$mm_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$testpos[w$variables$majorityminority == 0], design = w[w$variables$majorityminority == 0], na.rm = TRUE, deff = TRUE)
  daily$mw[d] <- coef(dailytemp)
  daily$mw_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$testpos[w$variables$povertyq1 == 1], design = w[w$variables$povertyq1 == 1], na.rm = TRUE, deff = TRUE)
  daily$q1[d] <- coef(dailytemp)
  daily$q1_se[d] <- SE(dailytemp)[1]
  
  dailytemp <- svymean(w$variables$testpos[w$variables$povertyq1 == 0], design = w[w$variables$povertyq1 == 0], na.rm = TRUE, deff = TRUE)
  daily$q24[d] <- coef(dailytemp)
  daily$q24_se[d] <- SE(dailytemp)[1]
}

sevars <- names(daily)[substr(names(daily), str_length(names(daily))-2, str_length(names(daily)))=="_se"]
sevars
for(sevar in sevars){
  civar <- substr(sevar, 1, str_length(sevar)-3)
  print(civar)
  civar_ci_l <- paste(civar,"_ci_l", sep="")
  civar_ci_u <- paste(civar,"_ci_u", sep="")
  daily[civar_ci_l] <- daily[civar] - (daily[sevar] * 1.96)
  daily[civar_ci_u] <- daily[civar] + (daily[sevar] * 1.96)
}

write.csv(daily, file = "Kurzman-Covid-19-Delphi-Survey-Daily-Summary-2020-09-09.csv", row.names = FALSE)

# Drop several days with small samples (<35,000)

daily <- daily[daily$n >= 35000,]

# MAKE GRAPHS:

# FIGURE 1: Trend in respondents who tested positive for COVID-19, juxtaposed with Johns Hopkins data on active cases of COVID-19

testpos_daily <- ggplot(daily[daily$date>="2020-04-06",], aes(x = date)) +
  geom_point(aes(y = testpos), size=0.3, color = "Black", alpha = 0.5) + 
  geom_linerange(aes(ymin = testpos_ci_l, ymax = testpos_ci_u), color = "Black", alpha = 0.6) + 
  geom_line(aes(y=jhuactive), color = "Red", alpha = 0.5) + 
  geom_smooth(aes(y = testpos), se = FALSE, size=0.3, color = "Black", alpha = 0.5) +
  scale_y_continuous(breaks = seq(0,1.2, by=.2)) + expand_limits(y = 1.2) + expand_limits(y = 0) +
  ylab("Percent testing positive for Covid-19       ") +
  theme(panel.background=element_blank()) +
  xlab("Daily Surveys, April 6-September 7, 2020") +
  scale_x_date(date_breaks = "1 month", date_labels = "%B") +
  annotate(geom="text",x=as.Date("2020-04-21"), y=0.08, label="Active cases of Covid-19\nas percent of U.S. population,\nJohns Hopkins University Coronavirus Resource Center", hjust="left", size=3.5, color="red") +
  annotate(geom="text",x=as.Date("2020-05-01"), y=0.71, label="Survey respondents,\npercent reporting positive test\nand 95% confidence intervals", hjust="left", size=3.5, color="black") +
  labs(title = "Prevalence of Covid-19 in the United States, April 6-September 7, 2020") +
  labs(caption="Charles Kurzman, UNC-Chapel Hill, September 9, 2020.\nData sources: Delphi Research Group, Carnegie Mellon University; Johns Hopkins University Coronavirus Resource Center.", color="black")
  
testpos_daily

ggsave("c:/d/archive/CMU/Kurzman-Covid-19-Prevalence-2020-09-09.png", testpos_daily, dpi=300, height=4, width=8)

# FIGURE 2: Healthcare/eldercare workers, other workers, non-workers and testing, by day

# How many days was the difference statistically significant at p<.05
t <- table(daily$healthelder_ci_l > daily$nonhealthelder_ci_u)
t
prop.table(t)

# Cumulative data: mean of means and standard error of standard errors
daily$healthelder_variance <- ((daily$healthelder_ci_u - daily$healthelder_ci_l)/3.92)^2
testpos_healthelder_cumulative <- data.frame(mean(daily$healthelder, na.rm = TRUE))
names(testpos_healthelder_cumulative)[1] <- "mean"
testpos_healthelder_cumulative$se <- mean(daily$healthelder_variance, na.rm = TRUE)^0.5
testpos_healthelder_cumulative$date <- as.Date("2020-09-09")

daily$nonhealthelder_variance <- ((daily$nonhealthelder_ci_u - daily$nonhealthelder_ci_l)/3.92)^2
testpos_nonhealthelder_cumulative <- data.frame(mean(daily$nonhealthelder, na.rm = TRUE))
names(testpos_nonhealthelder_cumulative)[1] <- "mean"
testpos_nonhealthelder_cumulative$se <- mean(daily$nonhealthelder_variance, na.rm = TRUE)^0.5
testpos_nonhealthelder_cumulative$date <- as.Date("2020-09-09")

# Mean of means
testpos_healthelder_cumulative
testpos_nonhealthelder_cumulative

# Ratio of healthcare/eldercare workers to other respondents
testpos_healthelder_cumulative$mean/testpos_nonhealthelder_cumulative$mean

# Significance of cumulative means?
testpos_healthelder_cumulative$mean - 1.96*testpos_healthelder_cumulative$se
testpos_nonhealthelder_cumulative$mean + 1.96*testpos_nonhealthelder_cumulative$se

# How many days was workers rate higher than nonworkers rate
t <- table(daily$healthcare > daily$nonhealthelder)
t
prop.table(t)

# Block ci_l from going < 0 on chart:
daily$healthelder_ci_l[daily$healthelder_ci_l<0] <- 0

he_testpos_daily <- ggplot(daily[daily$date>="2020-04-06",], aes(x = date)) +
  geom_point(aes(y = healthelder), color="Black", size=0.3) + 
  geom_linerange(aes(ymin = healthelder_ci_l, ymax = healthelder_ci_u), color = "Black", alpha = 0.6) + 
  geom_smooth(aes(y = healthelder), se = FALSE, color = "Black", size=0.3) +
  geom_point(aes(y=nonhealthelder), color = "Red", size=0.3) +
  geom_linerange(aes(ymin = nonhealthelder_ci_l, ymax = nonhealthelder_ci_u), color = "Red", alpha = 0.6) +
  geom_smooth(aes(y = nonhealthelder), se = FALSE, color = "Black", size=0.3) +
  theme(panel.background=element_blank()) +
  scale_y_continuous(breaks = seq(0,2.6, by=0.2)) + expand_limits(y = 0) + expand_limits(y = 2.6) +
  ylab("Percent testing positive for Covid-19") +
  xlab("Daily Surveys, April 6-September 7, 2020") +
  scale_x_date(date_breaks = "1 month", date_labels = "%B") +
  annotate(geom="text",x=as.Date("2020-04-08"), y=1.7, label="Survey respondents\nworking outside the home in healthcare or eldercare,\npercent reporting positive tests\nand 95% confidence intervals", hjust="left", size=3.5, color="black") +
  annotate(geom="text",x=as.Date("2020-05-13"), y=0.15, label="Other respondents", hjust="left", size=3.5, color="Red") +
  annotate(geom="text",x=as.Date("2020-09-09"), y=0.15, label="Total,\nall dates", hjust="center", size=3.5, color="Black") +
  geom_linerange(data = testpos_healthelder_cumulative, aes(ymin = mean - (1.96*se), ymax = mean + (1.96*se)), color="Black", alpha = 0.6) + 
  geom_linerange(data = testpos_nonhealthelder_cumulative, aes(ymin = mean - (1.96*se), ymax = mean + (1.96*se)), color="Red", alpha = 0.6) +
  geom_point(data = testpos_healthelder_cumulative, aes(y = mean), color="Black") +
  geom_point(data = testpos_nonhealthelder_cumulative, aes(y = mean), color="Red") +
  labs(title = "Prevalence of Covid-19 Among Healthcare and Eldercare Workers") +
  labs(caption="Charles Kurzman, UNC-Chapel Hill, September 9, 2020.\nData source: Delphi Research Group, Carnegie Mellon University.", color="black")

he_testpos_daily

ggsave("c:/d/archive/CMU/Kurzman-Covid-19-Healthcare-Eldercare-Workers-2020-09-09.png", he_testpos_daily, dpi=300, height=4, width=8)


# FIGURE 3: Worked outside the home

# How many days was workers rate higher than nonworkers rate
t <- table(daily$workers > daily$nonworkers)
t
prop.table(t)

# How many daily samples were statistically significant
t <- table(daily$workers_ci_l > daily$nonworkers_ci_u)
t
prop.table(t)

# Cumulative data: mean of means and standard error of standard errors
daily$workers_variance <- ((daily$workers_ci_u - daily$workers_ci_l)/3.92)^2
workers_cumulative <- data.frame(mean(daily$workers, na.rm = TRUE))
names(workers_cumulative)[1] <- "mean"
workers_cumulative$se <- mean(daily$workers_variance, na.rm = TRUE)^0.5
workers_cumulative$date <- as.Date("2020-09-09")

daily$nonworkers_variance <- ((daily$nonworkers_ci_u - daily$nonworkers_ci_l)/3.92)^2
nonworkers_cumulative <- data.frame(mean(daily$nonworkers, na.rm = TRUE))
names(nonworkers_cumulative)[1] <- "mean"
nonworkers_cumulative$se <- mean(daily$nonworkers_variance, na.rm = TRUE)^0.5
nonworkers_cumulative$date <- as.Date("2020-09-09")

# Mean of means
workers_cumulative
nonworkers_cumulative

# Ratio of workers to nonworkers
workers_cumulative$mean/nonworkers_cumulative$mean

# Statistically significant difference?
workers_cumulative$mean - (1.96*workers_cumulative$se)
nonworkers_cumulative$mean + (1.96*nonworkers_cumulative$se)

workers_ili5_daily <- ggplot(daily[daily$date>="2020-04-06",], aes(x = date)) +
  geom_point(aes(y = workers), size=0.3, color = "Black") + 
  geom_linerange(aes(ymin = workers_ci_l, ymax = workers_ci_u), color = "Black", alpha = 0.6) + 
  geom_point(aes(y=nonworkers), size=0.3, color = "Red") +
  geom_linerange(aes(ymin = nonworkers_ci_l, ymax = nonworkers_ci_u), color = "Red", alpha = 0.6) +
  geom_smooth(aes(y = workers), se = FALSE, color = "Black", size=0.3) +
  geom_smooth(aes(y = nonworkers), se = FALSE, color = "Black", size=0.3) +
  scale_y_continuous(breaks = seq(0,2.6, by=0.2)) + expand_limits(y = 0) + expand_limits(y = 2.6) +
  ylab("Percent recent onset of influenza-like illness") +
  theme(panel.background=element_blank()) +
  xlab("Daily Surveys, April 6-September 7, 2020") +
  scale_x_date(date_breaks = "1 month", date_labels = "%B") +
  annotate(geom="text",x=as.Date("2020-04-30"), y=1.55, label="Survey respondents\nworking outside the home in the past 5 days,\npercent reporting recent onset of influenza-like illness\nand 95% confidence intervals", hjust="left", size=3.5, color="black") +
  annotate(geom="text",x=as.Date("2020-04-08"), y=0.4, label="Respondents not working\noutside the home in the past 5 days", hjust="left", size=3.5, color="Red") +
  annotate(geom="text",x=as.Date("2020-09-09"), y=0.4, label="Total,\nall dates", hjust="center", size=3.5, color="Black") +
  geom_point(data = workers_cumulative, aes(y = mean), color="Black") +
  geom_point(data = nonworkers_cumulative, aes(y = mean), color="Red") +
  geom_linerange(data = workers_cumulative, aes(ymin = mean - (1.96*se), ymax = mean + (1.96*se)), color="Black", alpha = 0.6) + 
  geom_linerange(data = nonworkers_cumulative, aes(ymin = mean - (1.96*se), ymax = mean + (1.96*se)), color="Red", alpha = 0.6) +
  labs(title = "Essential Workers and Influenza-Like Illness in the United States") +
  labs(caption="Charles Kurzman, UNC-Chapel Hill, September 9, 2020.\nData source: Delphi Research Group, Carnegie Mellon University.", color="black")

workers_ili5_daily

ggsave("c:/d/archive/CMU/Kurzman-Influenza-Like-Illness-Essential-Workers-2020-09-09.png", workers_ili5_daily, dpi=300, height=4, width=8)


# FIGURE 4: Positive tests for COVID-19, by racial/ethnic composition of respondents' zipcodes

# How many days was the difference statistically significant at p<.05
t <- table(daily$mm_ci_l > daily$mw_ci_u)
t
prop.table(t)

# Cumulative data: mean of means and standard error of standard errors
daily$mm_variance <- ((daily$mm_ci_u - daily$mm_ci_l)/3.92)^2
mm_cumulative <- data.frame(mean(daily$mm, na.rm = TRUE))
names(mm_cumulative)[1] <- "mean"
mm_cumulative$se <- mean(daily$mm_variance, na.rm = TRUE)^0.5
mm_cumulative$date <- as.Date("2020-09-09")

daily$mw_variance <- ((daily$mw_ci_u - daily$mw_ci_l)/3.92)^2
mw_cumulative <- data.frame(mean(daily$mw, na.rm = TRUE))
names(mw_cumulative)[1] <- "mean"
mw_cumulative$se <- mean(daily$mw_variance, na.rm = TRUE)^0.5
mw_cumulative$date <- as.Date("2020-09-09")

# Mean of means
mm_cumulative
mw_cumulative

# Ratio of majority-minority to majority-white zipcodes
mm_cumulative$mean/mw_cumulative$mean

mm_daily <- ggplot(daily[daily$date>="2020-04-06",], aes(x = date)) +
  geom_point(aes(y = mm), size=0.3, color = "Black") + 
  geom_linerange(aes(ymin = mm_ci_l, ymax = mm_ci_u), color = "Black", alpha = 0.6) + 
  geom_point(aes(y=mw), size=0.3, color = "Red") +
  geom_linerange(aes(ymin = mw_ci_l, ymax = mw_ci_u), color = "Red", alpha = 0.6) +
  geom_smooth(aes(y = mm), se = FALSE, color = "Black", size=0.3) +
  geom_smooth(aes(y = mw), se = FALSE, color = "Black", size=0.3) +
  scale_y_continuous(breaks = seq(0,2.6, by=0.2)) + expand_limits(y = 0) + expand_limits(y = 2.6) +
  ylab("Percent testing positive for Covid-19") +
  theme(panel.background=element_blank()) +
  xlab("Daily Surveys, April 6-September 7, 2020") +
  scale_x_date(date_breaks = "1 month", date_labels = "%B") +
  annotate(geom="text",x=as.Date("2020-04-30"), y=1.64, label="Survey respondents\nin majority-minority zipcodes,\npercent reporting positive tests\nand 95% confidence intervals", hjust="left", size=3.5, color="black") +
  annotate(geom="text",x=as.Date("2020-05-25"), y=0.10, label="Respondents in\nmajority-white zipcodes", hjust="left", size=3.5, color="Red") +
  annotate(geom="text",x=as.Date("2020-09-09"), y=0.14, label="Total,\nall dates", hjust="center", size=3.5, color="Black") +
  geom_linerange(data = mm_cumulative, aes(ymin = mean - (1.96*se), ymax = mean + (1.96*se)), color="Black", alpha = 0.6) + 
  geom_linerange(data = mw_cumulative, aes(ymin = mean - (1.96*se), ymax = mean + (1.96*se)), color="Red", alpha = 0.6) + 
  geom_point(data = mm_cumulative, aes(y = mean), color="Black") +
  geom_point(data = mw_cumulative, aes(y = mean), color="Red") +
  labs(title = "Racial Disparity in Prevalence of Covid-19 in the United States") +
  labs(caption="Charles Kurzman, UNC-Chapel Hill, September 9, 2020.\nData source: Delphi Research Group, Carnegie Mellon University.", color="black")

mm_daily

ggsave("c:/d/archive/CMU/Kurzman-Covid-19-Majority-Minority-Zipcodes-2020-09-09.png", dpi=300, height=4, width=8)

# FIGURE 5: Positive tests for COVID-19, by median income quartiles of respondents' zipcodes

# Cumulative data: mean of means and standard error of standard errors
daily$q1_variance <- ((daily$q1_ci_u - daily$q1_ci_l)/3.92)^2
q1_cumulative <- data.frame(mean(daily$q1, na.rm = TRUE))
names(q1_cumulative)[1] <- "mean"
q1_cumulative$se <- mean(daily$q1_variance, na.rm = TRUE)^0.5
q1_cumulative$date <- as.Date("2020-09-09")

daily$q24_variance <- ((daily$q24_ci_u - daily$q24_ci_l)/3.92)^2
q24_cumulative <- data.frame(mean(daily$q24, na.rm = TRUE))
names(q24_cumulative)[1] <- "mean"
q24_cumulative$se <- mean(daily$q24_variance, na.rm = TRUE)^0.5
q24_cumulative$date <- as.Date("2020-09-09")

# Mean of means
q1_cumulative
q24_cumulative

# Ratio of positive tests in low-income zipcodes to other zipcodes
q1_cumulative$mean/q24_cumulative$mean

q1_daily <- ggplot(daily[daily$date>="2020-04-06",], aes(x = date)) +
  geom_point(aes(y = q1), size=0.3, color = "Black") + 
  geom_linerange(aes(ymin = q1_ci_l, ymax = q1_ci_u), color = "Black", alpha = 0.6) + 
  geom_point(aes(y=q24), size=0.3, color = "Red") +
  geom_linerange(aes(ymin = q24_ci_l, ymax = q24_ci_u), color = "Red", alpha = 0.6) +
  geom_smooth(aes(y = q1), se = FALSE, color = "Black", size=0.3) +
  geom_smooth(aes(y = q24), se = FALSE, color = "Black", size=0.3) +
  scale_y_continuous(breaks = seq(0,2.6, by=0.2)) + expand_limits(y = 0) + expand_limits(y = 2.6) +
  ylab("Percent testing positive for Covid-19") +
  theme(panel.background=element_blank()) +
  xlab("Daily Surveys, April 6-September 7, 2020") +
  scale_x_date(date_breaks = "1 month", date_labels = "%B") +
  annotate(geom="text",x=as.Date("2020-04-28"), y=1.34, label="Survey respondents\nin low-income zipcodes,\npercent reporting positive tests\nand 95% confidence intervals", hjust="left", size=3.5, color="black") +
  annotate(geom="text",x=as.Date("2020-05-25"), y=0.10, label="Respondents in\nother zipcodes", hjust="left", size=3.5, color="Red") +
  annotate(geom="text",x=as.Date("2020-09-09"), y=0.14, label="Total,\nall dates", hjust="center", size=3.5, color="Black") +
  geom_linerange(data = q1_cumulative, aes(ymin = mean - (1.96*se), ymax = mean + (1.96*se)), color="Black", alpha = 0.6) + 
  geom_linerange(data = q24_cumulative, aes(ymin = mean - (1.96*se), ymax = mean + (1.96*se)), color="Red", alpha = 0.6) + 
  geom_point(data = q1_cumulative, aes(y = mean), color="Black") +
  geom_point(data = q24_cumulative, aes(y = mean), color="Red") +
  labs(title = "Income Disparity in Prevalence of Covid-19 in the United States") +
  labs(caption="Charles Kurzman, UNC-Chapel Hill, September 9, 2020.\nData source: Delphi Research Group, Carnegie Mellon University.", color="black")

q1_daily

ggsave("c:/d/archive/CMU/Kurzman-Covid-19-Low-Income-Zipcodes-2020-09-09.png", dpi=300, height=4, width=8)


# Table 1: Descriptive statistics

testpos.table <- svytable(~testpos, w, Ntotal = nrow(w$variables))
testpos.table
prop.table(testpos.table)

ili5.table <- svytable(~ili5, w, Ntotal = nrow(w$variables))
ili5.table
prop.table(ili5.table)

he.table <- svytable(~healthelder, w, Ntotal = nrow(w$variables))
he.table
prop.table(he.table)

work.table <- svytable(~work, w, Ntotal = nrow(w$variables))
work.table
prop.table(work.table)

mm.table <- svytable(~majorityminority, w, Ntotal = nrow(w$variables))
mm.table
prop.table(mm.table)

q1.table <- svytable(~povertyq1, w, Ntotal = nrow(w$variables))
q1.table
prop.table(q1.table)

health <- svytable(~healthcare+testpos, w, Ntotal = nrow(w$variables))
health
prop.table(health, 1)

elder <- svytable(~eldercare+testpos, w, Ntotal = nrow(w$variables))
elder
prop.table(elder, 1)
