# Charles Kurzman, University of North Carolina at Chapel Hill
# Compile Delphi Covid-19 survey and related datasets

#install.packages("tibble")
library(tibble)
#install.packages("tidyverse")
library(tidyverse)     # group_by
#install.packages("stringr")
library(stringr)       # str_detect
#install.packages("questionr")
library(questionr)     # wtd.table
#install.packages("survey")
library(survey)        # svydesign, svytable
#install.packages("spatstat")
library(spatstat)      # weighted.quantile
#install.packages("readxl)
library(readxl)        # read.xlsx
#install.packages("dplyr")
library(dplyr)

# Download files from Delphi Research Group, Carnegie Mellon University:
# WinSCP: ftp.delphi.cmu.edu

# Open data files:
setwd("C:/d/archive/CMU/downloads/")
filelist <- list.files() # Get filenames
head(filelist)
filelist <- filelist[str_detect(filelist, "recordedby")] # Keep only "recordedby" filenames
filelist <- filelist[order(filelist)] # Alphabetize filenames
filelist <- data.frame(filelist, stringsAsFactors = FALSE)
head(filelist$filelist)
filelist$responsedate <- substr(filelist$filelist,16,25) # Get response date from filenames
head(filelist)
filelist <- filelist %>% # Keep only the last filename for each response date
  group_by(responsedate) %>% 
  slice(tail(row_number(), 1))
head(filelist)
tail(filelist)
lastdate <- max(filelist$responsedate)
lastdate <- str_replace_all(lastdate, "_","-")
lastdate

# Open first data file
r <- read.csv(filelist$filelist[1], stringsAsFactors=FALSE)
# Drop unused variables to make file smaller
r <- r[,names(r) %in% c("StartDatetime","A3","A3b","B2","B2b","B5","C3","C4","C5","C10_1_1","C10_2_1","C10_3_1","C7","D1","D2","weight")]
r$date <- as.Date(filelist$responsedate[1], format="%Y_%m_%d")
# Loop through rest of data files, drop unused variables, and append to previous files
for(f in 2:length(filelist$filelist)) {
  print(filelist$filelist[f])
  temp <- read.csv(filelist$filelist[f], stringsAsFactors=FALSE)
  temp <- temp[,names(temp) %in% c("StartDatetime","A3","A3b","B2","B2b","B5","C3","C4","C5","C10_1_1","C10_2_1","C10_3_1","C7","D1","D2","weight")]	
  temp$date <- as.Date(filelist$responsedate[f], format="%Y_%m_%d")
  r <- bind_rows(r, temp)
  rm(temp)
}
rm(f)

# Add zipcode level data from the Census Bureau's American Community Study

setwd("c:/d/archive/CMU/zipcodes/")

# Median income by zipcode, 2018 American Community Study, downloaded June 28, 2020
# From https://data.census.gov/cedsci/table?q=income&g=0100000US.860000&tid=ACSST5Y2018.S1901&t=Income%20%28Households,%20Families,%20Individuals%29&hidePreview=true&vintage=2018
acszipcodeincome <- read.csv("c:/d/archive/CMU/zipcodes/ACSST5Y2018.S1901_data_with_overlays_2020-06-24T092312.csv", stringsAsFactors = FALSE)
acsi <- data.frame()[0:nrow(acszipcodeincome),]
acsi$medianincome <- as.numeric(acszipcodeincome$S1901_C01_012E)
acsi$zipcode <- substr(acszipcodeincome$GEO_ID,10,14)
acsi[1:10,]
summary(acsi$medianincome)
rm(acszipcodeincome)
povertyq <- quantile(acsi$medianincome, probs = seq(0, 1, 0.25), na.rm = TRUE)
povertyq
write.csv(povertyq, "c:/d/archive/CMU/zipcodes/medianincomequartiles.csv")

# Race/Hispanic ethnicity by zipcode, 2018 American Community Study, downloaded June 28, 2020
# From https://data.census.gov/cedsci/table?g=0100000US.860000&d=ACS%205-Year%20Estimates%20Detailed%20Tables&tid=ACSDT5Y2018.B02001&hidePreview=false&vintage=2018&t=Race%20and%20Ethnicity
acszipcoderace <- read.csv("c:/d/archive/CMU/zipcodes/ACSDT5Y2018.B02001_data_with_overlays_2020-06-24T153408.csv", stringsAsFactors = FALSE)
acsr <- data.frame()[0:nrow(acszipcoderace),]
acsr$whitealonepct <- 100*as.numeric(acszipcoderace$B02001_002E)/as.numeric(acszipcoderace$B02001_001E)
acsr$whitealonepct[2000:2010]
acsr$zipcode <- substr(acszipcoderace$GEO_ID,10,14)
acsr[1:10,]
summary(acsr$whitealonepct)
rm(acszipcoderace)

# Merge survey data with zipcode data
r <- merge(r, acsi, by.x = "A3", by.y = "zipcode", all.x = TRUE)
r <- merge(r, acsr, by.x = "A3", by.y = "zipcode", all.x = TRUE)
rm(acsi)
rm(acsr)

r <- r[order(r$StartDatetime),]

# Save as csv
#write.csv(r, file = "cmu-data-2020-09-08.csv", row.names = FALSE)

# Johns Hopkins University Coronavirus Research Center, https://coronavirus.jhu.edu/data/cumulative-cases
# Download daily datafiles
start <- as.Date("04-12-2020",format="%m-%d-%Y")
end   <- as.Date(lastdate,format="%Y-%m-%d")
d <- start
while(d<=end) {
  localfile <- paste("c:/d/archive/CMU/JHU/JHU-",d,".csv", sep="")
  if(!file.exists(localfile)) {
    jhu <- paste("https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_daily_reports_us/",format(d, "%m-%d-%Y"),".csv",sep="")
    download.file(jhu,localfile)
    print(localfile)
    }
  d <- d+1
}
